import { Predicate } from './types';
/**
 * Returns a function that calls predicates and returns true if all of them are satisfied, otherwise returns false
 *

 *
 * @example
 * const isBetween10And100 = is.all(is.greaterThan(10), is.lessThan(100));
 *
 * isBetween10And100(0); // false
 * isBetween10And100(11); // true
 *
 * @throws {TypeError} if not every predicate is a function
 */
export default function all(...predicates: (Predicate | Function)[]): Predicate;
