"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assertPredicates_1 = require("./utils/assertPredicates");
var description_1 = require("./utils/description");
var typeToPredicate_1 = require("./typeToPredicate");
/**
 * Returns a function that calls predicates and returns true if all of them are satisfied, otherwise returns false
 *

 *
 * @example
 * const isBetween10And100 = is.all(is.greaterThan(10), is.lessThan(100));
 *
 * isBetween10And100(0); // false
 * isBetween10And100(11); // true
 *
 * @throws {TypeError} if not every predicate is a function
 */
function all() {
    var predicates = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        predicates[_i] = arguments[_i];
    }
    var convertedPredicates = predicates.map(function (p) { return typeToPredicate_1.getPredicateForType(p) || p; });
    assertPredicates_1.default(convertedPredicates);
    return description_1.setDescription(function () {
        var _this = this;
        var args = arguments;
        return convertedPredicates.every(function (predicate) { return predicate.apply(_this, args); });
    }, 'a value that satisfies all predicates: ' + (convertedPredicates.map(description_1.getDescription)).join(', '));
}
exports.default = all;
