import { Predicate } from './types';
/**
 * Returns a function that calls predicates in the order until one of them will be satisfied, otherwise returns false.
 *
 *
 * @example
 * const isStringOrNumber = is.any(is.string, is.number);
 *
 * isStringOrNumber(0); // true
 * isStringOrNumber('string'); // true
 * isStringOrNumber(undefined); // false
 *
 * @throws {TypeError} if not every predicate is a function
 */
export default function any(...predicates: (Predicate | Function)[]): Predicate;
