"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assertPredicates_1 = require("./utils/assertPredicates");
var description_1 = require("./utils/description");
var typeToPredicate_1 = require("./typeToPredicate");
/**
 * Returns a function that calls predicates in the order until one of them will be satisfied, otherwise returns false.
 *
 *
 * @example
 * const isStringOrNumber = is.any(is.string, is.number);
 *
 * isStringOrNumber(0); // true
 * isStringOrNumber('string'); // true
 * isStringOrNumber(undefined); // false
 *
 * @throws {TypeError} if not every predicate is a function
 */
function any() {
    var predicates = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        predicates[_i] = arguments[_i];
    }
    var convertedPredicates = predicates.map(function (p) { return typeToPredicate_1.getPredicateForType(p) || p; });
    assertPredicates_1.default(convertedPredicates);
    return description_1.setDescription(function anyPredicate() {
        var _this = this;
        var args = arguments;
        return convertedPredicates.some(function (predicate) { return predicate.apply(_this, args); });
    }, 'a value that satisfies any of predicates: ' + (convertedPredicates.map(description_1.getDescription)).join(', '));
}
exports.default = any;
