"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var object_1 = require("./object");
var number_1 = require("./number");
var description_1 = require("./utils/description");
/**
 * Checks whether a value looks like an array
 * That means:
 * * is an object
 * * has 'length' property
 * * 'length' property is a number greater or equal 0
 *
 * @example
 * is.arrayLike(arguments); // true
 * is.arrayLike(document.querySelectorAll('div')); // true
 * is.arrayLike([1, 2, 3]); // true
 * is.arrayLike({}); // false
 */
function isArrayLike(value) {
    return object_1.default(value) && number_1.default(value.length) && value.length >= 0;
}
exports.default = isArrayLike;
description_1.setDescription(isArrayLike, 'an array like object');
