import { Predicate, TypeGuardPredicate } from './types';
/**
 * Checks whether every element of an array passes the predicate
 *
 * @example
 * const isArrayOfStrings = is.arrayOf(is.string);
 *
 * isArrayOfStrings(['1', '2']); // true
 * // same as
 * is.arrayOf(is.string, ['1', '2']); // true
 * // same as
 * is.arrayOf(String, ['1', '2']); // true
 *
 * isArrayOfStrings([1, 2]); // false
 *
 * @throws {TypeError} if predicate is not a function
 */
declare function isArrayOf<T = any>(predicate: Predicate | Function): TypeGuardPredicate<Array<T>>;
declare function isArrayOf<T = any>(predicate: Predicate | Function, value: any[]): value is Array<T>;
export default isArrayOf;
