"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var object_1 = require("./object");
var string_1 = require("./string");
var arrayLike_1 = require("./arrayLike");
var description_1 = require("./utils/description");
/**
 * Checks whether a value is empty
 * Value is empty when:
 * * is an array like object with length === 0
 * * is an object without enumerable properties
 * * is an empty string
 * * is undefined
 *
 * @example
 * is.empty(''); // true
 * is.empty([]); // true
 * is.empty({}); // true
 * is.empty(undefined); // true
 * is.empty([1]); // false
 * is.empty('test'); // false
 */
function isEmpty(value) {
    if (arrayLike_1.default(value)) {
        return value.length === 0;
    }
    else if (object_1.default(value)) {
        return Object.keys(value).length === 0;
    }
    else if (string_1.default(value)) {
        return value == '';
    }
    return value === void 0;
}
description_1.setDescription(isEmpty, 'an empty value');
exports.default = isEmpty;
