import { Predicate } from './types';
/**
 * Checks whether an object has own property
 *
 * @example
 * const isCustomized = is.hasOwnProperty('delay');
 *
 * const Timer = function() {};
 * Timer.prototype.delay = 100;
 *
 * const timer1 = new Timer();
 * const timer2 = new Timer();
 * timer1.delay = 1000;
 *
 * isCustomized(timer1) // true
 * // same as
 * is.hasOwnProperty('delay', timer1); // true
 *
 * isCustomized(timer2); // false
 *
 * @throws {TypeError} if property is not a string or a symbol
 */
declare function hasOwnProperty(property: string | Symbol): Predicate;
declare function hasOwnProperty(property: string | Symbol, object: object): boolean;
export default hasOwnProperty;
