"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var function_1 = require("./function");
var handleCurry_1 = require("./utils/handleCurry");
var description_1 = require("./utils/description");
/**
 * Negates result of a predicate
 *
 * @example
 * const isNotEmpty = is.not(is.empty);
 * isNotEmpty([1, 2]);// true
 * // same as
 * is.not(is.empty, [1, 2]); // true
 * isNotEmpty(''); // false
 */
function isNot(predicate) {
    if (!function_1.default(predicate)) {
        throw new TypeError('Predicate must be a function');
    }
    return handleCurry_1.default.call(this, arguments, description_1.setDescription(function () {
        return !predicate.apply(this, arguments);
    }, 'not ' + description_1.getDescription(predicate)));
}
exports.default = isNot;
