import { Predicate, TypeGuardPredicate } from './types';
/**
 * Checks whether a value is undefined or satisfies given predicate
 * Very useful to check optional arguments of function.
 *
 * @example
 * const isUndefinedOrString = is.undefinedOr(is.string);
 *
 * isUndefinedOrString(undefined); // true
 * isUndefinedOrString('test'); // true
 *
 * // same as
 * is.undefinedOr(is.string, undefined); // true
 * is.undefinedOr(is.string, 'test'); // true
 *
 * isUndefinedOrString({}); // false
 *
 * // simpler for common types
 * is.undefinedOr(String)(undefined); // true
 * is.undefinedOr(String)('test'); // true
 *
 * @throws {TypeError} if provided predicate is not a function
 */
declare function isUndefinedOr<T = any>(predicate: Predicate | Function): TypeGuardPredicate<undefined | T>;
declare function isUndefinedOr<T = any>(predicate: Predicate | Function, value: any): value is (undefined | T);
export default isUndefinedOr;
