import { Predicate } from "../types";
export declare const descriptionKey = "__predicateDescription";
/**
 * Sets description of predicate.
 *
 * Underneath assigns a non-enumerable property to a given predicate
 *
 * @example
 *
 * function customPredicate(value) {
 *  // implementation
 * }
 *
 * is.setDescription(customPredicate, 'some custom description')
 * is.getDescription(customPredicate); // 'some custom description'
 */
export declare function setDescription<T extends Predicate>(predicate: T, desc: string): T;
/**
 * Returns predicate description
 *
 * @example
 * is.getDescription(is.string); // 'a string'
 *
 * function someCustomPredicate(value) {
 *   // implementation
 * }
 * is.getDescription(someCustomPredicate); // 'satisfied custom predicate "someCustomPredicate"'
 *
 * is.getDescription(function(value) {}); // 'satisfied custom predicate "anonymous"'
 */
export declare function getDescription(predicate: Predicate): string;
