"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.descriptionKey = '__predicateDescription';
/**
 * Sets description of predicate.
 *
 * Underneath assigns a non-enumerable property to a given predicate
 *
 * @example
 *
 * function customPredicate(value) {
 *  // implementation
 * }
 *
 * is.setDescription(customPredicate, 'some custom description')
 * is.getDescription(customPredicate); // 'some custom description'
 */
function setDescription(predicate, desc) {
    Object.defineProperty(predicate, exports.descriptionKey, {
        value: desc,
        enumerable: false
    });
    return predicate;
}
exports.setDescription = setDescription;
/**
 * Returns predicate description
 *
 * @example
 * is.getDescription(is.string); // 'a string'
 *
 * function someCustomPredicate(value) {
 *   // implementation
 * }
 * is.getDescription(someCustomPredicate); // 'satisfied custom predicate "someCustomPredicate"'
 *
 * is.getDescription(function(value) {}); // 'satisfied custom predicate "anonymous"'
 */
function getDescription(predicate) {
    var desc = predicate[exports.descriptionKey];
    if (typeof desc === 'string') {
        return desc;
    }
    return 'satisfies custom predicate "' + (predicate.name || 'anonymous') + '"';
}
exports.getDescription = getDescription;
